@@ -29,12 +29,18 @@ void DEF_videoandsound ()
     // Video Defaults
 
     diff += CHECKBUTTON_fullscreen		    -> value (0);
-    diff += CHOICE_windowsize                       -> value (0); // WS_640x480
+    diff += CHOICE_windowsize                       -> value (1); // WS_800x600
 
     // Sound Defaults
    
     diff += CHECKBUTTON_soundeffects		    -> value (1);
 
+    // Colors
+
+    diff += CHECKBUTTON_usecolorfile	    -> value (0);
+    FILEINPUT_colorfile			    -> deactivate ();
+    BUTTON_browsecolorfile		    -> deactivate ();
+
     if (diff)
       BUTTON_apply->activate();
 }
@@ -234,6 +240,8 @@ void DEF_saving ()
     FILEINPUT_alternatesavedir			    -> deactivate ();
     BUTTON_browsealternatesavedir		    -> deactivate ();
 
+    diff += CHECKBUTTON_startblank                  -> value(0);
+
     if (diff)
       BUTTON_apply->activate();
 }
